@@ -4,7 +4,7 @@ use strict;
 use vars qw($VERSION);
 use Carp qw(confess);
 
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 my %masks;
 my @fields = qw(PACK UNPACK NBITS MASKS);
@@ -336,7 +336,7 @@ sub find {
     my %results;
     my $in_range;
     $self->prep_find unless $self->{FIND};
-    return {} unless @_;
+    return {} unless @_ and @{$self->{FIND}};
     return $self->bin_find(@_) if @_/@{$self->{FIND}} < $self->{PCT};
     my @ips = sort map { $pack->($_) || confess "Bad IP: $_" } @_;
     my $last;
@@ -438,6 +438,8 @@ of CIDR address ranges. Works for IPv4 and IPv6 addresses.
 
 =head1 METHODS
 
+=over 4
+
 =item new() 
 
  $cidr = Net::CIDR::Lite->new
@@ -572,6 +574,8 @@ not necessarily what the original argument looked like). E.g. removes
 unnecessary leading zeros, removes null blocks from IPv6
 addresses, etc.
 
+=back
+
 =head1 CAVEATS
 
 Garbage in/garbage out. This module does do validation, but maybe
